==> freecycle-0.3alpha.tar.bz2: freecycle/src/defs.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Predrag Viceic                                  *
 *   viceic@net2000.ch                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DEFS_H
#define DEFS_H
#include <stdio.h>
#include <iostream.h>
#include <cassert>
#include <limits.h>
#include <float.h>
template <class T>
inline void zap(T & x)
{
        {assert(x != NULL);}
        delete x;
        x = NULL;
}

template <class T>
inline void zaparr(T & x)
{
         {assert(x != NULL);}
     delete [] x;
     x = NULL;
}
static char* release="Freecycle v0.3alpha";
static const int RTTI_BEATLINE=1001;
static const int RTTI_BPMLINE=1002;
static const int RTTI_LOOPMARKER=1003;
static const int RTTI_MEASUREMARKER=1004;
static const int RTTI_VALUELINE=1005;
static const int RTTI_DRAWINGLINE=1006;
static const int RTTI_POLYLINE=1007;
static const int RTTI_SPLINELINE=1008;

#endif

==> freecycle-0.4alpha.tar.bz2: freecycle/src/defs.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Predrag Viceic                                  *
 *   viceic@net2000.ch                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DEFS_H
#define DEFS_H
#include <stdio.h>
#include <iostream.h>
#include <cassert>
#include <limits.h>
#include <float.h>
template <class T>
inline void zap(T & x)
{
        {assert(x != NULL);}
        delete x;
        x = NULL;
}

template <class T>
inline void zaparr(T & x)
{
         {assert(x != NULL);}
     delete [] x;
     x = NULL;
}
static char* release_no="0.4alpha";
static char* release="Freecycle 0.4alpha";
static const int RTTI_BEATLINE=1001;
static const int RTTI_BPMLINE=1002;
static const int RTTI_LOOPMARKER=1003;
static const int RTTI_MEASUREMARKER=1004;
static const int RTTI_VALUELINE=1005;
static const int RTTI_DRAWINGLINE=1006;
static const int RTTI_POLYLINE=1007;
static const int RTTI_SPLINELINE=1008;
static const int RTTI_LOCKEDBEATRECT=1009;

#endif
